package com.logicbig.example;


import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;

public class EditableComboBoxExample {
    public static void main(String[] args) {
        //create a JTable
        JTable table = TableHelper.createTable();

        //create combo box as a search component
        JComboBox<String> searchComboBox = new JComboBox<>();
        searchComboBox.setEditable(true);
        searchComboBox.addActionListener(createSearchActionListener(searchComboBox, table));

        //wrap comboBox in a panel
        JPanel panel = new JPanel();
        panel.add(new JLabel("Search"));
        panel.add(searchComboBox);

        //frame
        JFrame frame = createFrame();
        frame.add(panel, BorderLayout.NORTH);
        frame.add(new JScrollPane(table));
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }

    private static ActionListener createSearchActionListener(JComboBox<String> comboBox, JTable table) {
        return e -> {
            if ("comboBoxChanged".equals(e.getActionCommand())) {
                String searchText = (String) comboBox.getSelectedItem();
                searchText = searchText.trim().toLowerCase();
                //if there are matches then add the search text in combo for later use
                if (TableHelper.searchInTable(table, searchText)) {
                    DefaultComboBoxModel<String> model = (DefaultComboBoxModel<String>) comboBox.getModel();
                    //check if search text is not empty and model already doesn't have it.
                    if (!searchText.isEmpty() && model.getIndexOf(searchText) == -1) {
                        model.addElement(searchText);
                    }
                }
            }
        };
    }

    private static JFrame createFrame() {
        JFrame frame = new JFrame("JComboBox Example");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(new Dimension(600, 500));
        return frame;
    }
}